==> cordova-plugin-misnap-1.0.7.tgz: package/src/ios/MiSnap.m <==
#import "MiSnap.h"
#import <Cordova/CDVAvailability.h>

@implementation MiSnap

- (void)takePicture:(CDVInvokedUrlCommand *)command
{
    self.cmd = command;

    NSString* documentType = [command argumentAtIndex:0];

    MiSnapSDKViewController *mvc = (MiSnapSDKViewController *)[[UIStoryboard storyboardWithName:@"MiSnapUX2" bundle:nil] instantiateViewControllerWithIdentifier:@"MiSnapSDKViewControllerUX2"];
    mvc.delegate = self;

    NSMutableDictionary* parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewControllerUX2 defaultParametersForACH]];
    [parameters setObject:@"Production" forKey:kMiSnapServerType];
    [parameters setObject:@"4.8.0" forKey:kMiSnapServerVersion];

    if([documentType isEqualToString:@"CheckFront"])
    {
        parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewControllerUX2 defaultParametersForCheckFront]];
        [parameters setObject:@"Mobile Deposit Check Front" forKey:kMiSnapShortDescription];
    }
    else if([documentType isEqualToString:@"CheckBack"])
    {
        parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewControllerUX2 defaultParametersForCheckBack]];
        [parameters setObject:@"Mobile Deposit Check Back" forKey:kMiSnapShortDescription];
    }
    [mvc setupMiSnapWithParams:parameters];

    //mvc.modalTransitionStyle = UIModalTransitionStyleCrossDissolve;
    // Set modalPresentationStyle to Full Screen explicitly to avoid undefined behavior on iOS 13 and newer
    //mvc.modalPresentationStyle = UIModalPresentationFullScreen;
    
    [self.viewController presentViewController:mvc animated:YES completion:nil];
}

#pragma mark -
#pragma mark MiSnap Delegate methods

-(void)miSnapCancelledWithResults:(NSDictionary *)results
{
    NSMutableDictionary* mibiDataAndImages = [[NSMutableDictionary alloc]init];
    [mibiDataAndImages setObject:@"Cancelled" forKey:@"ResultCode"];
    
    CDVPluginResult *pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:mibiDataAndImages];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:self.cmd.callbackId];
}

- (void)miSnapFinishedReturningEncodedImage:(NSString *)encodedImage originalImage:(UIImage *)image andResults:(NSDictionary *)results
{
    NSMutableDictionary* mibiDataAndImages = [[NSMutableDictionary alloc]init];
    [mibiDataAndImages setObject:encodedImage forKey:@"EncodedImage"];
    [mibiDataAndImages setObject:@"ImageCaptured" forKey:@"ResultCode"];
    
    CDVPluginResult *pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:mibiDataAndImages];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:self.cmd.callbackId];
}

@end

==> cordova-plugin-misnap-1.0.12.tgz: package/src/ios/MiSnap.m <==
#import "MiSnap.h"
#import <Cordova/CDVAvailability.h>

@implementation MiSnap

- (void)takePicture:(CDVInvokedUrlCommand *)command
{
    self.cmd = command;

    NSString* documentType = [command argumentAtIndex:0];

    MiSnapSDKViewController *mvc = (MiSnapSDKViewController *)[[UIStoryboard storyboardWithName:@"MiSnapUX2" bundle:nil] instantiateViewControllerWithIdentifier:@"MiSnapSDKViewControllerUX2"];
    mvc.delegate = self;

    NSMutableDictionary* parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewController defaultParametersForCheckFront]];
    [parameters setObject:@"Production" forKey:kMiSnapServerType];
    [parameters setObject:@"4.8.0" forKey:kMiSnapServerVersion];

    if([documentType isEqualToString:@"CheckFront"])
    {
        parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewController defaultParametersForCheckFront]];
        [parameters setObject:@"CheckFront" forKey:kMiSnapDocumentType];
        [parameters setObject:@"Check Front2" forKey:kMiSnapShortDescription];
    }
    else if([documentType isEqualToString:@"CheckBack"])
    {
        parameters = [NSMutableDictionary dictionaryWithDictionary:[MiSnapSDKViewController defaultParametersForCheckBack]];
        [parameters setObject:@"CheckBack" forKey:kMiSnapDocumentType];
        [parameters setObject:@"Check Back2" forKey:kMiSnapShortDescription];
    }

    [mvc setupMiSnapWithParams:parameters];

    //mvc.modalTransitionStyle = UIModalTransitionStyleCrossDissolve;
    // Set modalPresentationStyle to Full Screen explicitly to avoid undefined behavior on iOS 13 and newer
    mvc.modalPresentationStyle = UIModalPresentationFullScreen;
    
    [self.viewController presentViewController:mvc animated:YES completion:nil];
}

#pragma mark -
#pragma mark MiSnap Delegate methods

-(void)miSnapCancelledWithResults:(NSDictionary *)results
{
    NSMutableDictionary* mibiDataAndImages = [[NSMutableDictionary alloc]init];
    [mibiDataAndImages setObject:@"Cancelled" forKey:@"ResultCode"];
    
    CDVPluginResult *pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:mibiDataAndImages];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:self.cmd.callbackId];
}

- (void)miSnapFinishedReturningEncodedImage:(NSString *)encodedImage originalImage:(UIImage *)originalImage andResults:(NSDictionary *)results forDocumentType:(NSString *)docType
{
    NSMutableDictionary* mibiDataAndImages = [[NSMutableDictionary alloc]init];
    [mibiDataAndImages setObject:encodedImage forKey:@"EncodedImage"];
    [mibiDataAndImages setObject:@"ImageCaptured" forKey:@"ResultCode"];
    
    CDVPluginResult *pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:mibiDataAndImages];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:self.cmd.callbackId];
}

- (void)miSnapFinishedReturningEncodedImage:(NSString *)encodedImage originalImage:(UIImage *)image andResults:(NSDictionary *)results
{
    NSMutableDictionary* mibiDataAndImages = [[NSMutableDictionary alloc]init];
    [mibiDataAndImages setObject:encodedImage forKey:@"EncodedImage"];
    [mibiDataAndImages setObject:@"ImageCaptured" forKey:@"ResultCode"];
    
    CDVPluginResult *pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:mibiDataAndImages];
    [self.commandDelegate sendPluginResult:pluginResult callbackId:self.cmd.callbackId];
}

@end
